==> qupzilla_1.4.1.orig.tar.gz: qupzilla-1.4.1.orig/src/plugins/MouseGestures/translations/sr_BA@latin.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr@latin" version="2.0">
<context>
    <name>MouseGesturesSettingsDialog</name>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="14"/>
        <source>Mouse Gestures</source>
        <translation>Gestovi miša</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="42"/>
        <source>&lt;h1&gt;Mouse Gestures&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;Gestovi miša&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="64"/>
        <source>Press and hold the middle mouse button and move your mouse in the indicated directions.</source>
        <translation>Pritisnite i držite srednji taster miša i pomjerajte miša u navedenim smjerovima.</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="111"/>
        <source>&lt;b&gt;Stop&lt;/b&gt;&lt;br/&gt;Stop loading page</source>
        <translation>&lt;b&gt;Zaustavi&lt;/b&gt;&lt;br/&gt;Zaustavi učitavanje stranice</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="125"/>
        <source>&lt;b&gt;New tab&lt;/b&gt;&lt;br/&gt;Open new tab</source>
        <translation>&lt;b&gt;Novi jezičak&lt;/b&gt;&lt;br/&gt;Otvori novi jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="139"/>
        <source>&lt;b&gt;Back&lt;/b&gt;&lt;br/&gt;Go back in history</source>
        <translation>&lt;b&gt;Nazad&lt;/b&gt;&lt;br/&gt;Idi nazad u istorijatu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="159"/>
        <source>&lt;b&gt;Reload&lt;/b&gt;&lt;br/&gt;Reload page</source>
        <translation>&lt;b&gt;Ponovo učitaj&lt;/b&gt;&lt;br/&gt;Ponovo učitaj stranicu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="173"/>
        <source>&lt;b&gt;Close tab&lt;/b&gt;&lt;br/&gt;Close current tab</source>
        <translation>&lt;b&gt;Zatvori jezičak&lt;/b&gt;&lt;br/&gt;Zatvori tekući jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="187"/>
        <source>&lt;b&gt;Forward&lt;/b&gt;&lt;br/&gt;Go forward in history</source>
        <translation>&lt;b&gt;Naprijed&lt;/b&gt;&lt;br/&gt;Idi naprijed u istorijatu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="194"/>
        <source>&lt;b&gt;Previous tab&lt;/b&gt;&lt;br/&gt;Switch to previous tab</source>
        <translation>&lt;b&gt;Prethodni jezičak&lt;/b&gt;&lt;br/&gt;Prebaci na prethodni jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="208"/>
        <source>&lt;b&gt;Home&lt;/b&gt;&lt;br/&gt;Go to homepage</source>
        <translation>&lt;b&gt;Domaća&lt;/b&gt;&lt;br/&gt;Idi na domaću stranicu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="222"/>
        <source>&lt;b&gt;Next tab&lt;/b&gt;&lt;br/&gt;Switch to next tab</source>
        <translation>&lt;b&gt;Sljedeći jezičak&lt;/b&gt;&lt;br/&gt;Prebaci na sljedeći jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="253"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
</context>
</TS>

==> qupzilla_1.6.0.orig.tar.gz: qupzilla-1.6.0/src/plugins/MouseGestures/translations/sr_BA@latin.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr_BA@latin" version="2.0">
<context>
    <name>MouseGesturesSettingsDialog</name>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="14"/>
        <source>Mouse Gestures</source>
        <translation>Gestovi miša</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="42"/>
        <source>&lt;h1&gt;Mouse Gestures&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;Gestovi miša&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="64"/>
        <source>Press and hold the middle mouse button and move your mouse in the indicated directions.</source>
        <translation>Pritisnite i držite srednji taster miša i pomjerajte miša u navedenim smjerovima.</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="111"/>
        <source>&lt;b&gt;Stop&lt;/b&gt;&lt;br/&gt;Stop loading page</source>
        <translation>&lt;b&gt;Zaustavi&lt;/b&gt;&lt;br/&gt;Zaustavi učitavanje stranice</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="125"/>
        <source>&lt;b&gt;New tab&lt;/b&gt;&lt;br/&gt;Open new tab</source>
        <translation>&lt;b&gt;Novi jezičak&lt;/b&gt;&lt;br/&gt;Otvori novi jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="139"/>
        <source>&lt;b&gt;Back&lt;/b&gt;&lt;br/&gt;Go back in history</source>
        <translation>&lt;b&gt;Nazad&lt;/b&gt;&lt;br/&gt;Idi nazad u istorijatu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="159"/>
        <source>&lt;b&gt;Reload&lt;/b&gt;&lt;br/&gt;Reload page</source>
        <translation>&lt;b&gt;Ponovo učitaj&lt;/b&gt;&lt;br/&gt;Ponovo učitaj stranicu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="173"/>
        <source>&lt;b&gt;Close tab&lt;/b&gt;&lt;br/&gt;Close current tab</source>
        <translation>&lt;b&gt;Zatvori jezičak&lt;/b&gt;&lt;br/&gt;Zatvori tekući jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="187"/>
        <source>&lt;b&gt;Forward&lt;/b&gt;&lt;br/&gt;Go forward in history</source>
        <translation>&lt;b&gt;Naprijed&lt;/b&gt;&lt;br/&gt;Idi naprijed u istorijatu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="194"/>
        <source>&lt;b&gt;Previous tab&lt;/b&gt;&lt;br/&gt;Switch to previous tab</source>
        <translation>&lt;b&gt;Prethodni jezičak&lt;/b&gt;&lt;br/&gt;Prebaci na prethodni jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="208"/>
        <source>&lt;b&gt;Home&lt;/b&gt;&lt;br/&gt;Go to homepage</source>
        <translation>&lt;b&gt;Domaća&lt;/b&gt;&lt;br/&gt;Idi na domaću stranicu</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="222"/>
        <source>&lt;b&gt;Next tab&lt;/b&gt;&lt;br/&gt;Switch to next tab</source>
        <translation>&lt;b&gt;Sljedeći jezičak&lt;/b&gt;&lt;br/&gt;Prebaci na sljedeći jezičak</translation>
    </message>
    <message>
        <location filename="../mousegesturessettingsdialog.ui" line="253"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
</context>
</TS>
